@@ -19,6 +19,11 @@ import aws_cdk.aws_sqs
 import aws_cdk.core
 import aws_cdk.cx_api
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-lambda", "1.34.0", __name__[0:-6], "aws-lambda@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
